Stan Math Library: stan/math/prim/scal/meta/child_type.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
child_type.hpp File Reference

Go to the source code of this file.

## Classes
struct | stan::math::child_type< T >
| Primary template class for metaprogram to compute child type of T. More...
struct | stan::math::child_type< T_struct< T_child > >
| Specialization for template classes / structs. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.